@@ -217,13 +217,13 @@ class Equals(Formula):
 
     def to_sql(self) -> str:
         if isinstance(self.left, Variable):
-            left_string = f'{self.left.name}'
+            left_string = f'"{self.left.name}"'
         elif isinstance(self.left, str):
             left_string = f'\'{str(self.left)}\''
         else:
             left_string = f'{str(self.left)}'
         if isinstance(self.right, Variable):
-            right_string = f'{self.right.name}'
+            right_string = f'"{self.right.name}"'
         elif isinstance(self.right, str):
             right_string = f'\'{str(self.right)}\''
         else:
@@ -249,11 +249,11 @@ class GreaterEquals(Formula):
 
     def to_sql(self) -> str:
         if isinstance(self.left, Variable):
-            left_string = f'{self.left.name}'
+            left_string = f'"{self.left.name}"'
         else:
             left_string = f'{str(self.left)}'
         if isinstance(self.right, Variable):
-            right_string = f'{self.right.name}'
+            right_string = f'"{self.right.name}"'
         else:
             right_string = f'{str(self.right)}'
 
@@ -277,11 +277,11 @@ class GreaterThan(Formula):
 
     def to_sql(self) -> str:
         if isinstance(self.left, Variable):
-            left_string = f'{self.left.name}'
+            left_string = f'"{self.left.name}"'
         else:
             left_string = f'{str(self.left)}'
         if isinstance(self.right, Variable):
-            right_string = f'{self.right.name}'
+            right_string = f'"{self.right.name}"'
         else:
             right_string = f'{str(self.right)}'
 
@@ -305,11 +305,11 @@ class LessEquals(Formula):
 
     def to_sql(self) -> str:
         if isinstance(self.left, Variable):
-            left_string = f'{self.left.name}'
+            left_string = f'"{self.left.name}"'
         else:
             left_string = f'{str(self.left)}'
         if isinstance(self.right, Variable):
-            right_string = f'{self.right.name}'
+            right_string = f'"{self.right.name}"'
         else:
             right_string = f'{str(self.right)}'
 
@@ -333,11 +333,11 @@ class LessThan(Formula):
 
     def to_sql(self) -> str:
         if isinstance(self.left, Variable):
-            left_string = f'{self.left.name}'
+            left_string = f'"{self.left.name}"'
         else:
             left_string = f'{str(self.left)}'
         if isinstance(self.right, Variable):
-            right_string = f'{self.right.name}'
+            right_string = f'"{self.right.name}"'
         else:
             right_string = f'{str(self.right)}'
 
